package Cairo::Install::Files;

$self = {
          'inc' => '-I. -Ibuild -I/usr/local/include/cairo -I/usr/local/include/libpng16 -I/usr/X11R6/include -I/usr/X11R6/include/freetype2 -I/usr/X11R6/include/pixman-1 -I/usr/local/include -I/usr/local/include/cairo -I/usr/local/include/libpng16 -I/usr/X11R6/include -I/usr/X11R6/include/pixman-1 -I/usr/X11R6/include/freetype2',
          'deps' => [],
          'libs' => '-L/usr/local/lib -lcairo -Wl,-rpath-link,/usr/X11R6/lib -L/usr/local/lib -lcairo -Wl,-rpath-link,/usr/X11R6/lib -L/usr/X11R6/lib -lfreetype',
          'typemaps' => [
                          'cairo-perl-auto.typemap',
                          'cairo-perl.typemap'
                        ]
        };


# this is for backwards compatiblity
@deps = @{ $self->{deps} };
@typemaps = @{ $self->{typemaps} };
$libs = $self->{libs};
$inc = $self->{inc};

	$CORE = undef;
	foreach (@INC) {
		if ( -f $_ . "/Cairo/Install/Files.pm") {
			$CORE = $_ . "/Cairo/Install/";
			last;
		}
	}

1;
